



# from ._version import __version__

# . then folder name followed by the python file name, and import the specific function
from .utils.misc import (set_log_level)
from .utils.nparray import (mesh_cor)






from setuptools import setup

setup(name='rpbtool',
      version='0.0.1',
      description='Tools that commonly used throught my career',
      author='rpb',
      packages=['rpbtool'],
      long_description='Tools that commonly used throught my career',
      install_requires=['mne','numpy','pandas','pickle'],
      )
